/*								-*- C++ -*-
 * $Id: wx_setup-Xt.h,v 1.5 1997-01-30 09:55:33+01 mho Exp $
 *
 * Purpose: Window library configuration file.
 *          Note: you may need to re-run xmkmf/imake after
 *                you have edited the setup!
 *
 * Authors: Markus Holzem and Julian Smart
 *
 * Copyright: (C) 1995, AIAI, University of Edinburgh (Julian)
 * Copyright: (C) 1995, GNU (Markus)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Additionally everyone using this library has to announce it with:
 *
 *   This software uses the wxWindows-Xt GUI library
 *   (C) Markus Holzem, available via
 *       ftp://ftp.aiai.ed.ac.uk/pub/packages/wxwin/ports/xt
 */

#ifndef wxSetup_h
#define wxSetup_h

#ifdef __GNUG__
#pragma interface
#endif

/*
 * This setup files contains the following sections:
 *
 *1. debugging features
 *2. compiler features
 *3. Windows 3.1 compatibility
 *4. wxWindows featurs enable/disable
 *5. Imakefile evaluations
 */

/**************************** DEBUGGING FEATURES ****************************/

/*
 * Enables debugging: memory tracing, assert, etc.
 */
#define WXDEBUG 0
/*
 * Enables output of X events (start application with -debugEvents)
 */
#define WXDEBUG_EVENTS 1
/*
 * Enables debugging version of wxObject::new and wxObject::delete (IF WXDEBUG)
 * WARNING: this code may not work with all architectures, especially
 * if alignment is an issue.
 */
#define USE_MEMORY_TRACING 1
/*
 * Enable debugging version of global memory operators new and delete
 * Disable it, If this causes problems (e.g. link errors)
 */
#define USE_GLOBAL_MEMORY_OPERATORS 1
/*
 * If WXDEBUG && USE_MEMORY_TRACING && USE_GLOBAL_MEMORY_OPERATORS
 * used to debug the memory allocation of wxWindows Xt port code
 */
#define USE_INTERNAL_MEMORY_TRACING 1
/*
 * Matthews garbage collection (used for MrEd?)
 */
#define WXGARBAGE_COLLECTION_ON 0

/**************************** COMPILER FEATURES *****************************/

/*
 * Disable this if your compiler can't cope
 * with omission of prototype parameters.
 */
#define REMOVE_UNUSED_ARG 1
/*
 * The const keyword is being introduced more in wxWindows.
 * You can use this setting to maintain backward compatibility.
 * If 0:	will use const wherever possible.
 * If 1:	will use const only where necessary
 *              for precompiled headers to work.
 * If 2:	will be totally backward compatible, but precompiled
 *	headers may not work and program size will be larger.
 */
#define CONST_COMPATIBILITY 0

/************************ WINDOWS 3.1 COMPATIBILITY *************************/

/*
 * Normalize X drawing code to behave exactly as MSW.
 */
#define WX_STANDARD_GRAPHICS 0

/**************************** WXWINDOWS FEATURES ****************************/

/*
 * Use font metric files in GetTextExtent for wxPostScriptDC
 * Use consistent PostScript fonts for AFM and printing (!)
 */
#define USE_AFM_FOR_POSTSCRIPT 1
#define WX_NORMALIZED_PS_FONTS 1
/*
 * Use clipboard
 */
#define USE_CLIPBOARD 1
/*
 * Use wxWindows layout constraint system
 */
#define USE_CONSTRAINTS 1
/*
 * Use the document/view architecture
 */
#define USE_DOC_VIEW_ARCHITECTURE 1
/*
 * Use enhanced dialog
 */
#define USE_ENHANCED_DIALOG 0
/*
 * Use Form panel item placement
 */
#define USE_FORM 1
/*
 * Use fraction class
 */
#define USE_FRACTION 1
/*
 * Use gauge item
 */
#define USE_GAUGE 1
/*
 * Implement a GLCanvas class as an interface to OpenGL, using the GLX
 * extension to the X11 protocol.  You can use the (free) Mesa library
 * if you don't have a 'real' OpenGL.
 */
#define USE_GLX 0
/*
 * Use the GNU wxString class instead of the AIAI class
 */
#define USE_GNU_WXSTRING 0
/*
 * Use wxWindows help facility (needs USE_IPC 1)
 */
#define USE_HELP 1
/*
 * Support image loading for wxBitmap (wxImage is needed for this)
 */
#define USE_IMAGE_LOADING 0
#define WXIMAGE_INCLUDE "../../utils/image/src/wx_image.h"
/*
 * Use Interprocess communication
 */
#define USE_IPC 1
/*
 * Use Metafile and Metafile device context
 */
#define USE_METAFILE 0
/*
 * Use PostScript device context
 */
#define USE_POSTSCRIPT 1
/*
 * Use the print/preview architecture
 */
#define USE_PRINTING_ARCHITECTURE 1
/*
 * Use Prolog IO
 */
#define USE_PROLOGIO 1
/*
 * Use Remote Procedure Call (Needs USE_IPC and USE_PROLOGIO)
 */
#define USE_RPC 0
/*
 * Use wxGetResource & wxWriteResource (change .Xdefaults)
 */
#define USE_RESOURCES 1
/*
 * Use scrollbar item
 */
#define USE_SCROLLBAR 1
/*
 * Use splines
 */
#define USE_SPLINES 1
/*
 * Use time and date classes
 */
#define USE_TIMEDATE 1
/*
 * Use Threads
 */
#define USE_THREADS 0
#define USE_THREADS_POSIX 0
#define USE_THREADS_SGI 0
/*
 * Use toolbar, use Xt port toolbar (3D look)
 */
#define USE_TOOLBAR 1
#define USE_XT_TOOLBAR 1
/*
 * Enables old type checking mechanism (wxSubType)
 */
#define USE_TYPETREE 1
/*
 * Use virtual list box item
 */
#define USE_VLBOX 0
/*
 * Use wxWindows resource loading (.wxr-files) (Needs USE_PROLOGIO 1)
 */
#define USE_WX_RESOURCES 1
/*
 * Use wxGraph
 */
#define USE_WXGRAPH 1
/*
 * Use wxTree
 */
#define USE_WXTREE 1
/*
 * Support XPM package in wxBitmap and wxIcon.
 * XPM_INCLUDE specifies, where to find the include-file for XPM
 * If you want to use it, you have to link in the XPM library to your applications.
 */
#define USE_XPM 1
#define XPM_INCLUDE <X11/xpm.h>

/********************** DO NOT CHANGE BELOW THIS POINT **********************/

/*
 * USE_DYNAMIC_CLASSES is TRUE for the Xt port
 */
#define USE_DYNAMIC_CLASSES 1
/*
 * USE_EXTENDED_STATICS is FALSE for the Xt port
*/
#define USE_EXTENDED_STATICS 0

/*************************** IMAKEFILE EVALUATIOS ***************************/

#ifndef InImakefile
#if USE_XPM
	#define USE_XPM_IN_X 1
#else
	#define USE_XPM_IN_X 0
#endif
#if USE_IMAGE_LOADING
	#define USE_IMAGE_LOADING_IN_X 1
#else
	#define USE_IMAGE_LOADING_IN_X 0
#endif
#endif

/*
 * Adjustions for Imakefile, allows skipping during compilation
 */
#ifdef InImakefile
#if USE_GNU_WXSTRING
	WXSTRING=DAT_gnustring.o DAT_gnuregex.o
#else
	WXSTRING=DAT_string.o
#endif
#if USE_THREADS
	THREADS=APP_thread.o
#endif
#if USE_RPC
	RPC=PRO_rpc.o
#endif
#if USE_WX_RESOURCES
	WXRESOURCES=WIN_resources.o
#endif
#if USE_PROLOGIO
	PROLOGIO=PRO_read.o PRO_parser.o
	PROLOGIOSRC=PRO_read.cc
#endif
#if USE_POSTSCRIPT
	POSTSCRIPTDC=DEV_psdc.o DLG_ps.o
#endif
#if USE_METAFILE
	METAFILEDC=DEV_metafiledc.o
#endif
#if USE_FORM
	FORM=HLV_form.o
#endif
#if USE_HELP
	HELP=IPC_help.o
#endif
#if USE_IPC
	IPC=IPC_base.o IPC_client.o IPC_socket.o IPC_server.o
#endif
#if USE_ENHANCED_DIALOG
	ENHDIALOGBOX=WIN_enhdialogbox.o
#endif
#if USE_RESOURCES
	XRESOURCES=UTL_resources.o
#endif
#if USE_CLIPBOARD
	CLIPBOARD=MSC_clipboard.o
#endif
#if USE_TIMEDATE
	TIMEDATE=MSC_date.o MSC_time.o
#endif
#if USE_FRACTION
	FRACTION=MSC_fraction.o
#endif
#if USE_CONSTRAINTS
	LAYOUT=WIN_layout.o
#endif
#if USE_TOOLBAR && USE_XT_TOOLBAR
	TOOLBAR=WIN_toolbar.o
#endif
#if USE_TOOLBAR && !USE_XT_TOOLBAR
	TOOLBAR=WIN_toolbar2.o
#endif
#if USE_GAUGE
	GAUGE=WIN_gauge.o
#endif
#if USE_EXTENDED_STATICS
	STATICITEMS=WIN_staticitems.o
#endif
#if USE_VLBOX
	VIRTLISTBOX=WIN_virtlistbox.o
#endif
#if USE_SCROLLBAR
	SCROLLBAR=WIN_scrollbar.o
#endif
#if USE_DOC_VIEW_ARCHITECTURE
	DOCVIEW=HLV_doc.o
#endif
#if USE_PRINTING_ARCHITECTURE
	PRINTPREVIEW=HLV_print.o
#endif
#if USE_TYPETREE
	TYPETREE=DAT_typetree.o
#endif
#if USE_WXGRAPH
	WXGRAPH=DRW_graph.o
#endif
#if USE_WXTREE
	WXTREE=DRW_tree.o
#endif
#if USE_GLX
	GLCANVAS=WIN_glcanvas.o
#endif

#endif /* InImakefile */

#endif /* wxSetup_h */
